@@ -26,7 +26,7 @@ import (
 // all the descendant modules present to create an output list of all the
 // resources present in rootDir and descendant modules
 func (tfv14 *TfV14) LoadIacDir(absRootDir string, options map[string]interface{}) (allResourcesConfig output.AllResourceConfigs, err error) {
-	return commons.NewTerraformDirectoryLoader(absRootDir, options).LoadIacDir()
+	return commons.NewTerraformDirectoryLoader(absRootDir, "0.14.0", options).LoadIacDir()
 }
 
 // Name returns name of the provider
