@@ -20,6 +20,7 @@ import (
 	"github.com/tenable/terrascan/pkg/mapper/convert"
 	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 const armEnableSoftDelete = "enableSoftDelete"
@@ -34,7 +35,7 @@ func KeyVaultConfig(r types.Resource, params map[string]interface{}) map[string]
 	return map[string]interface{}{
 		tfLocation:          fn.LookUpString(nil, params, r.Location),
 		tfName:              fn.LookUpString(nil, params, r.Name),
-		tfTags:              r.Tags,
+		tfTags:              functions.PatchAWSTags(r.Tags),
 		tfSoftDeleteEnabled: convert.ToBool(r.Properties, armEnableSoftDelete),
 		tfTenantID:          convert.ToString(params, armTenantID),
 	}
