@@ -20,6 +20,7 @@ import (
 	"github.com/tenable/terrascan/pkg/mapper/convert"
 	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 const (
@@ -39,7 +40,7 @@ func MSSQLServerConfig(r types.Resource, vars, params map[string]interface{}) ma
 	return map[string]interface{}{
 		tfLocation:                   fn.LookUpString(nil, params, r.Location),
 		tfName:                       fn.LookUpString(nil, params, r.Name),
-		tfTags:                       r.Tags,
+		tfTags:                       functions.PatchAWSTags(r.Tags),
 		tfAdministratorLogin:         fn.LookUpString(vars, params, convert.ToString(r.Properties, armAdministratorLogin)),
 		tfAdministratorLoginPassword: fn.LookUpString(vars, params, convert.ToString(r.Properties, armAdministratorLoginPassword)),
 		tfMinimumTLSVersion:          fn.LookUpString(vars, params, convert.ToString(r.Properties, armMinimumTLSVersion)),
