@@ -20,6 +20,7 @@ import (
 	"github.com/tenable/terrascan/pkg/mapper/convert"
 	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 const (
@@ -45,7 +46,7 @@ func NetworkSecurityRuleConfig(r types.Resource, params map[string]interface{})
 	return map[string]interface{}{
 		tfLocation:             fn.LookUpString(nil, params, r.Location),
 		tfName:                 fn.LookUpString(nil, params, r.Name),
-		tfTags:                 r.Tags,
+		tfTags:                 functions.PatchAWSTags(r.Tags),
 		tfAccess:               convert.ToString(r.Properties, armAccess),
 		tfDirection:            convert.ToBool(r.Properties, armDirection),
 		tfProtocol:             convert.ToString(r.Properties, armProtocol),
