@@ -29,10 +29,11 @@ type EbsVolumeConfig struct {
 }
 
 // GetEbsVolumeConfig returns config for aws_ebs_volume
+// aws_ebs_volume
 func GetEbsVolumeConfig(v *ec2.Volume) []AWSResourceConfig {
 	cf := EbsVolumeConfig{
 		Config: Config{
-			Tags: v.Tags,
+			Tags: functions.PatchAWSTags(v.Tags),
 		},
 		Encrypted: functions.GetVal(v.Encrypted),
 		KmsKeyID:  functions.GetVal(v.KmsKeyId),
