@@ -81,6 +81,7 @@ var ResourceTypes = map[string]string{
 	"AWS::ECS::TaskDefinition":                         AwsEcsTaskDefinition,
 	"AWS::S3::Bucket":                                  AwsS3Bucket,
 	"AWS::S3::Bucket.PublicAccessBlock":                AwsS3BucketPublicAccessBlock,
+	"AWS::S3::Bucket.ServerSideEncription":             AwsS3BucketServersideEncription,
 	"AWS::S3::BucketPolicy":                            AwsS3BucketPolicy,
 	"AWS::SQS::Queue":                                  AwsSqsQueue,
 	"AWS::SQS::QueuePolicy":                            AwsSqsQueuePolicy,
@@ -112,4 +113,5 @@ var ResourceTypes = map[string]string{
 	"AWS::EC2::Subnet":                                 AwsSubnet,
 	"AWS::EC2::Route":                                  AwsRoute,
 	"AWS::SSM::Parameter":                              AwsSSMParameter,
+	"AWS::ElasticLoadBalancingV2::LoadBalancer":        AwsLb,
 }
